"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRegisterEvents = void 0;
const react_1 = require("react");
const useSigma_1 = require("./useSigma");
const sigmaEvents = [
    "clickNode",
    "rightClickNode",
    "downNode",
    "enterNode",
    "leaveNode",
    "clickStage",
    "rightClickStage",
    "downStage",
    "kill",
];
const mouseEvents = ["click", "rightClick", "mouseup", "mousedown", "mousemove"];
const touchEvents = ["mouseup", "mousedown", "mousemove"];
const cameraEvents = ["cameraUpdated"];
function useRegisterEvents() {
    const sigma = useSigma_1.useSigma();
    const [eventHandlers, setEventHandlers] = react_1.useState({});
    react_1.useEffect(() => {
        let event;
        if (!sigma || !eventHandlers) {
            return;
        }
        for (event in eventHandlers) {
            const eventHandler = eventHandlers[event];
            if (sigmaEvents.includes(event)) {
                sigma.on(event, eventHandler);
            }
            if (mouseEvents.includes(event)) {
                sigma.getMouseCaptor().on(event, eventHandler);
            }
            if (touchEvents.includes(event)) {
                sigma.getTouchCaptor().on(event, eventHandler);
            }
            if (cameraEvents.includes(event)) {
                sigma.getCamera().on("updated", eventHandler);
            }
        }
        return () => {
            let event;
            for (event in eventHandlers) {
                const eventHandler = eventHandlers[event];
                if (sigmaEvents.includes(event)) {
                    sigma.removeListener(event, eventHandler);
                }
                if (mouseEvents.includes(event)) {
                    sigma.getMouseCaptor().removeListener(event, eventHandler);
                }
                if (touchEvents.includes(event)) {
                    sigma.getTouchCaptor().removeListener(event, eventHandler);
                }
                if (cameraEvents.includes(event)) {
                    sigma.getCamera().removeListener("updated", eventHandler);
                }
            }
        };
    }, [sigma, eventHandlers]);
    return setEventHandlers;
}
exports.useRegisterEvents = useRegisterEvents;
//# sourceMappingURL=useRegisterEvents.js.map